@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::SHARYANTO::NonCPAN::Task;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use Dist::Zilla::PluginBundle::Filter;
 
@@ -31,6 +31,10 @@ __END__
 
 Dist::Zilla::PluginBundle::Author::SHARYANTO::NonCPAN::Task - Dist::Zilla like SHARYANTO when you build your non-CPAN task dists
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
  # dist.ini
@@ -51,18 +55,17 @@ is equivalent to:
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at
-L<https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-SHARYANTO>.
+Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-SHARYANTO>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Dist-Zilla-PluginBundle-Author-SHARYANTO>.
+Source repository is at L<HASH(0x36b7908)>.
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Au
-thor-SHARYANTO
+https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-A
+uthor-SHARYANTO
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
